#include <EEPROM.h>
#include <Wire.h>

////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
// Maurice Ribble (Copyright 2012)
// Camera Axe - http://www.cameraaxe.com
// Open Source, licensed under a Creative Commons Attribution-NonCommercial 3.0 License (http://creativecommons.org/licenses/by-nc/3.0/)
// Compiled with Arduino Software 1.0 (http://arduino.cc)

// REVISIONS:
// 100  (5-03-2012) - Initial release

#define HW_RX_PIN              0
#define CAM0_FOCUS_PIN         1
#define BUTTON_ACTIVATE_PIN    2
#define CAM0_SHUTTER_PIN       3
#define CAM1_FOCUS_PIN         4
#define CAM1_SHUTTER_PIN       5
#define CAM2_FOCUS_PIN         6
#define CAM2_SHUTTER_PIN       7
#define CAM3_FOCUS_PIN         8
#define CAM3_SHUTTER_PIN       9
#define CAM4_FOCUS_PIN         10
#define CAM4_SHUTTER_PIN       11
#define CAM5_FOCUS_PIN         12
#define CAM5_SHUTTER_PIN       13
#define BUTTONS_APIN           0
#define BUTTONS_PIN            14
#define SEN_FOCUS_PIN          15
#define SEN_SHUTTER_PIN        16
#define LCD_BL_POW_PIN         17
#define LCD_BL_POW_APIN        3
#define I2C_SDA_PIN            18
#define I2C_SCL_PIN            19

enum { BUTTON_NONE, BUTTON_MENU_F, BUTTON_MENU_B, BUTTON_UP, BUTTON_DOWN, BUTTON_LEFT, BUTTON_RIGHT, BUTTON_ACTIVATE};
enum { MENUMODE_MENU, MENUMODE_PHOTO};

// Memory offsets into EEPROM (saves settings when power goes off)
enum {
  EEPROM_MODE,
  EEPROM_SERIES_PREFOCUS,
  EEPROM_SERIES_DELAY_SEC,
  EEPROM_SERIES_DELAY_MS,
  EEPROM_SERIES_DELAY_US,
  EEPROM_SERIES_DURATION_SEC,
  EEPROM_SERIES_DURATION_MS,
  EEPROM_SERIES_DURATION_US,
  EEPROM_SERIES_NUM_CAMS,
  EEPROM_SERIES_CUR_BANK,
  EEPROM_CUSTOM_DELAY_SEC1, 
  EEPROM_CUSTOM_DELAY_MS1,
  EEPROM_CUSTOM_DELAY_US1,
  EEPROM_CUSTOM_DURATION_SEC1,
  EEPROM_CUSTOM_DURATION_MS1,
  EEPROM_CUSTOM_DURATION_US1,
  EEPROM_CUSTOM_DELAY_SEC2, 
  EEPROM_CUSTOM_DELAY_MS2,
  EEPROM_CUSTOM_DELAY_US2,
  EEPROM_CUSTOM_DURATION_SEC2,
  EEPROM_CUSTOM_DURATION_MS2,
  EEPROM_CUSTOM_DURATION_US2,
  EEPROM_CUSTOM_DELAY_SEC3, 
  EEPROM_CUSTOM_DELAY_MS3,
  EEPROM_CUSTOM_DELAY_US3,
  EEPROM_CUSTOM_DURATION_SEC3,
  EEPROM_CUSTOM_DURATION_MS3,
  EEPROM_CUSTOM_DURATION_US3,
  EEPROM_CUSTOM_DELAY_SEC4, 
  EEPROM_CUSTOM_DELAY_MS4,
  EEPROM_CUSTOM_DELAY_US4,
  EEPROM_CUSTOM_DURATION_SEC4,
  EEPROM_CUSTOM_DURATION_MS4,
  EEPROM_CUSTOM_DURATION_US4,
  EEPROM_CUSTOM_DELAY_SEC5, 
  EEPROM_CUSTOM_DELAY_MS5,
  EEPROM_CUSTOM_DELAY_US5,
  EEPROM_CUSTOM_DURATION_SEC5,
  EEPROM_CUSTOM_DURATION_MS5,
  EEPROM_CUSTOM_DURATION_US5,
  EEPROM_CUSTOM_DELAY_SEC6, 
  EEPROM_CUSTOM_DELAY_MS6,
  EEPROM_CUSTOM_DELAY_US6,
  EEPROM_CUSTOM_DURATION_SEC6,
  EEPROM_CUSTOM_DURATION_MS6,
  EEPROM_CUSTOM_DURATION_US6,
  EEPROM_SIZE_PREVIOUS,
  EEPROM_SIZE  // EEPROM_SIZE must be at end of enum
};

// If EEPROM_SIZE ever gets over 512 we have a problem (atmega328 has 1028 bytes of eeprom)

byte g_menuMode     = MENUMODE_MENU;
byte g_cursorPos    = 0;
byte g_3cursorPos   = 0;
byte g_menuNum      = 0;
byte g_showCursorX  = 0;
byte g_showCursorY  = 0;

void setup()
{
  Serial.begin(9600); // open hw serial for debugging
  
  byte i;
  initPins();
  lcdInit(2, 16, 0x7C);
  lcdSetContrast(0);
  //lcdSetBacklight(LCD_BL_POW_APIN, 0);
  digitalWrite(LCD_BL_POW_PIN, HIGH);

  for(i=0; i<6; ++i)
    trigCam(i, HIGH, HIGH);

  
  
  validateEepromValues();
  
  // Holding activate button when turning on the Camera Axe forces a factory reset
  if ((detectButtonPress(false) == BUTTON_ACTIVATE) || 
      (eepromReadInt(EEPROM_SIZE_PREVIOUS) != (int)EEPROM_SIZE))
  {
    loadDefaultSettings();
    //testMode();
    buttonDebounce(10);  // 10 ms debounce
    eepromWriteInt(EEPROM_SIZE_PREVIOUS, (int)EEPROM_SIZE);
  }  
}

void loop()
{
  byte button;
  
  if (g_menuMode == MENUMODE_MENU)
    button = menuMode();
  else
    photoMode();
}


