////////////////////////////////////////
// Function: eepromWriteInt -  Writes an integer (16 bits) to eeprom
// Parameters:
//   addr - The address in eeprom to write to
//   val  - The value being written
// Returns:
//   None
////////////////////////////////////////
void eepromWriteInt(int addr, int val)
{
  addr *= 2;  // int is 2 bytes
  EEPROM.write(addr+1, val&0xFF);
  val /= 256;
  EEPROM.write(addr+0, val&0xFF);
}

////////////////////////////////////////
// Function: eepromWriteInt -  Reads an integer (16 bits) from eeprom
// Parameters:
//   addr - The address in eeprom to read from
// Returns:
//   The value being read from eeprom
////////////////////////////////////////
int eepromReadInt(int addr)
{
  int val;

  addr *= 2;  // int is 2 bytes
  val = EEPROM.read(addr+0);
  val *= 256;
  val |= EEPROM.read(addr+1);
  return val;
}

////////////////////////////////////////
// Function: eepromClamp -  Clamps the value in eeprom to the range given
// Parameters:
//   addr - The address in eeprom to read from
//   minVal  - Value being read clamps to this
//   maxVal  - Value being read clamps to this
// Returns:
//   The value being read from eeprom
////////////////////////////////////////
void eepromClamp(int addr, int minVal, int maxVal)
{
  int val1, val2;
  
  val1 = eepromReadInt(addr);
  val2 = constrain(val1, minVal, maxVal);
  if (val1 != val2)
    eepromWriteInt(addr, val2);
}
