////////////////////////////////////////
// Function: decimalToBcd - Converts a decimal to a BCD (binary coded decimal)
// Parameters:
//   dec - The decimal number
// Returns:
//   The BCD number
////////////////////////////////////////
unsigned int decimalToBcd(unsigned int dec)
{
  unsigned int bcd = 0;
  unsigned int i = 0;

  while (dec)
  {
    bcd += ((dec % 10)<<i);   // Convert lowest-order number
    i += 4;
    dec /= 10;
  }

  return(bcd);
}

////////////////////////////////////////
// Function: bcdToDecimal - Converts a BCD (binary coded decimal) to a decimal
// Parameters:
//   bcd - The bcd number
// Returns:
//   The decimal number
////////////////////////////////////////
unsigned int bcdToDecimal(unsigned int bcd)
{
  unsigned int dec = 0;
  unsigned int i = 1;

  while(bcd)
  {
    dec += (bcd & 0xF)*i;
    i *= 10;
    bcd = bcd >> 4;
  }

  return(dec);
}

////////////////////////////////////////
// Function: activeButtonIRS - The interupt service routine to handle pressing of the active button
// Parameters:
//   None
// Returns:
//   None
////////////////////////////////////////
void activeButtonISR()
{
  detachInterrupt(0);
  g_menuMode = MENUMODE_MENU;
  buttonDebounce(10); // 10 ms debounce
}


void trigCam(byte camNum, byte focus, byte shutter)
{
  switch (camNum)
  {
    case 0:
      digitalWrite(CAM0_FOCUS_PIN, focus);
      digitalWrite(CAM0_SHUTTER_PIN, shutter);
      break;
    case 1:
      digitalWrite(CAM1_FOCUS_PIN, focus);
      digitalWrite(CAM1_SHUTTER_PIN, shutter);
      break;
    case 2:
      digitalWrite(CAM2_FOCUS_PIN, focus);
      digitalWrite(CAM2_SHUTTER_PIN, shutter);
      break;
    case 3:
      digitalWrite(CAM3_FOCUS_PIN, focus);
      digitalWrite(CAM3_SHUTTER_PIN, shutter);
      break;
    case 4:
      digitalWrite(CAM4_FOCUS_PIN, focus);
      digitalWrite(CAM4_SHUTTER_PIN, shutter);
      break;
    case 5:
      digitalWrite(CAM5_FOCUS_PIN, focus);
      digitalWrite(CAM5_SHUTTER_PIN, shutter);
      break;
  }
}

