void initPins()
{
  pinMode(HW_RX_PIN, INPUT);
  pinMode(CAM0_FOCUS_PIN, OUTPUT);
  pinMode(BUTTON_ACTIVATE_PIN, INPUT);
  pinMode(CAM0_SHUTTER_PIN, OUTPUT);
  pinMode(CAM1_FOCUS_PIN, OUTPUT);
  pinMode(CAM1_SHUTTER_PIN, OUTPUT);
  pinMode(CAM2_FOCUS_PIN, OUTPUT);
  pinMode(CAM2_SHUTTER_PIN, OUTPUT);
  pinMode(CAM3_FOCUS_PIN, OUTPUT);
  pinMode(CAM3_SHUTTER_PIN, OUTPUT);
  pinMode(CAM4_FOCUS_PIN, OUTPUT);
  pinMode(CAM4_SHUTTER_PIN, OUTPUT);
  pinMode(CAM5_FOCUS_PIN, OUTPUT);
  pinMode(CAM5_SHUTTER_PIN, OUTPUT);
  pinMode(BUTTONS_PIN, INPUT);
  pinMode(SEN_FOCUS_PIN, INPUT);
  pinMode(SEN_SHUTTER_PIN, INPUT);
  pinMode(LCD_BL_POW_PIN, OUTPUT);
  
  digitalWrite(BUTTONS_PIN, HIGH);         // Turn on 20K pullup
  digitalWrite(BUTTON_ACTIVATE_PIN, HIGH);
  digitalWrite(SEN_FOCUS_PIN, HIGH);
  digitalWrite(SEN_SHUTTER_PIN, HIGH);
}

////////////////////////////////////////
// Function: loadDefaultSettings - Loads the default values into the eeprom
// Parameters:
//   None
// Returns:
//   None
////////////////////////////////////////
void loadDefaultSettings()
{
  eepromWriteInt(EEPROM_MODE,                      0);
  eepromWriteInt(EEPROM_SERIES_PREFOCUS,           0);
  eepromWriteInt(EEPROM_SERIES_DELAY_SEC,          0);
  eepromWriteInt(EEPROM_SERIES_DELAY_MS,           10);
  eepromWriteInt(EEPROM_SERIES_DELAY_US,           0);
  eepromWriteInt(EEPROM_SERIES_DURATION_SEC,       1);
  eepromWriteInt(EEPROM_SERIES_DURATION_MS,        0);
  eepromWriteInt(EEPROM_SERIES_DURATION_US,        0);
  eepromWriteInt(EEPROM_SERIES_NUM_CAMS,           6);
  eepromWriteInt(EEPROM_SERIES_CUR_BANK,           0);
  eepromWriteInt(EEPROM_CUSTOM_DELAY_SEC1,         0);
  eepromWriteInt(EEPROM_CUSTOM_DELAY_MS1,          0);
  eepromWriteInt(EEPROM_CUSTOM_DELAY_US1,          0);
  eepromWriteInt(EEPROM_CUSTOM_DURATION_SEC1,      0);
  eepromWriteInt(EEPROM_CUSTOM_DURATION_MS1,       0);
  eepromWriteInt(EEPROM_CUSTOM_DURATION_US1,       0);
  eepromWriteInt(EEPROM_CUSTOM_DELAY_SEC2,         0);
  eepromWriteInt(EEPROM_CUSTOM_DELAY_MS2,          0);
  eepromWriteInt(EEPROM_CUSTOM_DELAY_US2,          0);
  eepromWriteInt(EEPROM_CUSTOM_DURATION_SEC2,      0);
  eepromWriteInt(EEPROM_CUSTOM_DURATION_MS2,       0);
  eepromWriteInt(EEPROM_CUSTOM_DURATION_US2,       0);
  eepromWriteInt(EEPROM_CUSTOM_DELAY_SEC3,         0);
  eepromWriteInt(EEPROM_CUSTOM_DELAY_MS3,          0);
  eepromWriteInt(EEPROM_CUSTOM_DELAY_US3,          0);
  eepromWriteInt(EEPROM_CUSTOM_DURATION_SEC3,      0);
  eepromWriteInt(EEPROM_CUSTOM_DURATION_MS3,       0);
  eepromWriteInt(EEPROM_CUSTOM_DURATION_US3,       0);
  eepromWriteInt(EEPROM_CUSTOM_DELAY_SEC4,         0);
  eepromWriteInt(EEPROM_CUSTOM_DELAY_MS4,          0);
  eepromWriteInt(EEPROM_CUSTOM_DELAY_US4,          0);
  eepromWriteInt(EEPROM_CUSTOM_DURATION_SEC4,      0);
  eepromWriteInt(EEPROM_CUSTOM_DURATION_MS4,       0);
  eepromWriteInt(EEPROM_CUSTOM_DURATION_US4,       0);
  eepromWriteInt(EEPROM_CUSTOM_DELAY_SEC5,         0);
  eepromWriteInt(EEPROM_CUSTOM_DELAY_MS5,          0);
  eepromWriteInt(EEPROM_CUSTOM_DELAY_US5,          0);
  eepromWriteInt(EEPROM_CUSTOM_DURATION_SEC5,      0);
  eepromWriteInt(EEPROM_CUSTOM_DURATION_MS5,       0);
  eepromWriteInt(EEPROM_CUSTOM_DURATION_US5,       0);
  eepromWriteInt(EEPROM_CUSTOM_DELAY_SEC6,         0);
  eepromWriteInt(EEPROM_CUSTOM_DELAY_MS6,          0);
  eepromWriteInt(EEPROM_CUSTOM_DELAY_US6,          0);
  eepromWriteInt(EEPROM_CUSTOM_DURATION_SEC6,      0);
  eepromWriteInt(EEPROM_CUSTOM_DURATION_MS6,       0);
  eepromWriteInt(EEPROM_CUSTOM_DURATION_US6,       0);

  lcdSetCursorPos(0,0);
  lcdPrintStr("Resetting");
}

////////////////////////////////////////
// Function: validateEepromValues - Clamps values in eeprom to valid range
// Parameters:
//   None
// Returns:
//   None
////////////////////////////////////////
void validateEepromValues()
{
  eepromClamp(EEPROM_MODE, 0, 2);
  eepromClamp(EEPROM_SERIES_PREFOCUS, 0, 1);
  eepromClamp(EEPROM_SERIES_DELAY_SEC, 0, 999);
  eepromClamp(EEPROM_SERIES_DELAY_MS, 0, 999);
  eepromClamp(EEPROM_SERIES_DELAY_US, 0, 999);
  eepromClamp(EEPROM_SERIES_DURATION_SEC, 0, 999);
  eepromClamp(EEPROM_SERIES_DURATION_MS, 0, 999);
  eepromClamp(EEPROM_SERIES_DURATION_US, 0, 999);
  eepromClamp(EEPROM_SERIES_NUM_CAMS, 0, 999);
  eepromClamp(EEPROM_SERIES_CUR_BANK, 0, 999);
  eepromClamp(EEPROM_CUSTOM_DELAY_SEC1, 0, 999);
  eepromClamp(EEPROM_CUSTOM_DELAY_MS1, 0, 999);
  eepromClamp(EEPROM_CUSTOM_DELAY_US1, 0, 999);
  eepromClamp(EEPROM_CUSTOM_DURATION_SEC1, 0, 999);
  eepromClamp(EEPROM_CUSTOM_DURATION_MS1, 0, 999);
  eepromClamp(EEPROM_CUSTOM_DURATION_US1, 0, 999);
  eepromClamp(EEPROM_CUSTOM_DELAY_SEC2, 0, 999);
  eepromClamp(EEPROM_CUSTOM_DELAY_MS2, 0, 999);
  eepromClamp(EEPROM_CUSTOM_DELAY_US2, 0, 999);
  eepromClamp(EEPROM_CUSTOM_DURATION_SEC2, 0, 999);
  eepromClamp(EEPROM_CUSTOM_DURATION_MS2, 0, 999);
  eepromClamp(EEPROM_CUSTOM_DURATION_US2, 0, 999);
  eepromClamp(EEPROM_CUSTOM_DELAY_SEC3, 0, 999);
  eepromClamp(EEPROM_CUSTOM_DELAY_MS3, 0, 999);
  eepromClamp(EEPROM_CUSTOM_DELAY_US3, 0, 999);
  eepromClamp(EEPROM_CUSTOM_DURATION_SEC3, 0, 999);
  eepromClamp(EEPROM_CUSTOM_DURATION_MS3, 0, 999);
  eepromClamp(EEPROM_CUSTOM_DURATION_US3, 0, 999);
  eepromClamp(EEPROM_CUSTOM_DELAY_SEC4, 0, 999);
  eepromClamp(EEPROM_CUSTOM_DELAY_MS4, 0, 999);
  eepromClamp(EEPROM_CUSTOM_DELAY_US4, 0, 999);
  eepromClamp(EEPROM_CUSTOM_DURATION_SEC4, 0, 999);
  eepromClamp(EEPROM_CUSTOM_DURATION_MS4, 0, 999);
  eepromClamp(EEPROM_CUSTOM_DURATION_US4, 0, 999);
  eepromClamp(EEPROM_CUSTOM_DELAY_SEC5, 0, 999);
  eepromClamp(EEPROM_CUSTOM_DELAY_MS5, 0, 999);
  eepromClamp(EEPROM_CUSTOM_DELAY_US5, 0, 999);
  eepromClamp(EEPROM_CUSTOM_DURATION_SEC5, 0, 999);
  eepromClamp(EEPROM_CUSTOM_DURATION_MS5, 0, 999);
  eepromClamp(EEPROM_CUSTOM_DURATION_US5, 0, 999);
  eepromClamp(EEPROM_CUSTOM_DELAY_SEC6, 0, 999);
  eepromClamp(EEPROM_CUSTOM_DELAY_MS6, 0, 999);
  eepromClamp(EEPROM_CUSTOM_DELAY_US6, 0, 999);
  eepromClamp(EEPROM_CUSTOM_DURATION_SEC6, 0, 999);
  eepromClamp(EEPROM_CUSTOM_DURATION_MS6, 0, 999);
  eepromClamp(EEPROM_CUSTOM_DURATION_US6, 0, 999);
}
