
enum { MODE_MIRROR, MODE_SERIES, MODE_CUSTOM };

byte menuMode()
{
  byte button = BUTTON_NONE;

  lcdClear();  
  
  if(g_menuNum == 0)
  {
    const char modeStr[] = "Mirror|Series|Custom";
    lcdPrintStr(0, 0, "**Mode Select**");
    button = lcdSetString(0, 1, 1, 3, 6, EEPROM_MODE, modeStr);
  }
  
  if (eepromReadInt(EEPROM_MODE) == MODE_MIRROR)
  {
    menuMirror(button);
  }
  else if (eepromReadInt(EEPROM_MODE) == MODE_SERIES)
  {
    menuSeries(button);
  }
  else //(eepromReadInt(EEPROM_MODE) == MODE_CUSTOM
  {
    menuCustom(button);
  }
  
  lcdSetCursorPos(g_showCursorX, g_showCursorY);
  lcdSetShowCursor(1);
  delay(20);
  lcdSetShowCursor(0);
  
  return button;
}

void handleMenuButton(byte button, byte numMenus)
{
  if (button == BUTTON_MENU_F)
  {
    g_menuNum = (g_menuNum +1) % numMenus;
    g_cursorPos    = 0;
    g_3cursorPos   = 0;
  }
  else if (button == BUTTON_MENU_B)
  {
    g_menuNum = (g_menuNum == 0) ? (numMenus-1) : (g_menuNum-1);
    g_cursorPos    = 0;
    g_3cursorPos   = 0;
  }
  else if (button == BUTTON_ACTIVATE)
  {
     g_menuMode = MENUMODE_PHOTO; 
  }
}

void menuMirror(byte button)
{
  byte numMenus = 0;
  handleMenuButton(button, numMenus);
}

const char g_noYesStr[] = "No |Yes";
const char g_delayStr[] = "Delay ";
const char g_durationStr[] = "Duration ";

void menuSeries(byte button)
{
  byte numMenus = 6;
  
  if (button == BUTTON_NONE)
  {
    handleMenuButton(button, numMenus);
    button = BUTTON_NONE;
  }
  
  switch (g_menuNum)
  {
    case 0:
      break;
    case 1:
      lcdPrintStr(0, 0, "Prefocus");
      button = lcdSetString(0, 1, 1, 2, 3, EEPROM_SERIES_PREFOCUS, g_noYesStr);
      break;
    case 2:
      lcdPrintStr(0, 0, g_delayStr);
      button = lcdSetNumber3(0, 1, 1, &g_cursorPos, &g_3cursorPos, EEPROM_SERIES_DELAY_SEC, EEPROM_SERIES_DELAY_MS, EEPROM_SERIES_DELAY_US);
      break;
    case 3:
      lcdPrintStr(0, 0, g_durationStr);
      button = lcdSetNumber3(0, 1, 1, &g_cursorPos, &g_3cursorPos, EEPROM_SERIES_DURATION_SEC, EEPROM_SERIES_DURATION_MS, EEPROM_SERIES_DURATION_US);
      break;
    case 4:
      lcdPrintStr(0, 0, "Num Cam/Flashes");
      button = lcdSetNumber(0, 1, 1, &g_cursorPos, EEPROM_SERIES_NUM_CAMS, 9, 3, 0);
      break;
    case 5:
      lcdPrintStr(0, 0, "Cur Bank");
      button = lcdSetNumber(0, 1, 1, &g_cursorPos, EEPROM_SERIES_CUR_BANK, 9, 3, 0);
      break;
        
    default:
      g_menuNum = 0;
  }
  
  handleMenuButton(button, numMenus);
}

void menuCustom(byte button)
{
  byte numMenus = 14;
  
  if (button == BUTTON_NONE)
  {
    handleMenuButton(button, numMenus);
    button = BUTTON_NONE;
  }
  
  switch (g_menuNum)
  {
    case 0:
      break;
    case 1:
      lcdPrintStr(0, 0, "Prefocus");
      button = lcdSetString(0, 1, 1, 2, 3, EEPROM_SERIES_PREFOCUS, g_noYesStr);
      break;
    case 2:
      lcdPrintStr(0, 0, g_delayStr);
      lcdPrintDigit(1);
      button = lcdSetNumber3(0, 1, 1, &g_cursorPos, &g_3cursorPos, EEPROM_CUSTOM_DELAY_SEC1, EEPROM_CUSTOM_DELAY_MS1, EEPROM_CUSTOM_DELAY_US1);
      break;
    case 3:
      lcdPrintStr(0, 0, g_durationStr);
      lcdPrintDigit(1);
      button = lcdSetNumber3(0, 1, 1, &g_cursorPos, &g_3cursorPos, EEPROM_CUSTOM_DURATION_SEC1, EEPROM_CUSTOM_DURATION_MS1, EEPROM_CUSTOM_DURATION_US1);
      break;
    case 4:
      lcdPrintStr(0, 0, g_delayStr);
      lcdPrintDigit(2);
      button = lcdSetNumber3(0, 1, 1, &g_cursorPos, &g_3cursorPos, EEPROM_CUSTOM_DELAY_SEC2, EEPROM_CUSTOM_DELAY_MS2, EEPROM_CUSTOM_DELAY_US2);
      break;
    case 5:
      lcdPrintStr(0, 0, g_durationStr);
      lcdPrintDigit(2);
      button = lcdSetNumber3(0, 1, 1, &g_cursorPos, &g_3cursorPos, EEPROM_CUSTOM_DURATION_SEC2, EEPROM_CUSTOM_DURATION_MS2, EEPROM_CUSTOM_DURATION_US2);
      break;
    case 6:
      lcdPrintStr(0, 0, g_delayStr);
      lcdPrintDigit(3);
      button = lcdSetNumber3(0, 1, 1, &g_cursorPos, &g_3cursorPos, EEPROM_CUSTOM_DELAY_SEC3, EEPROM_CUSTOM_DELAY_MS3, EEPROM_CUSTOM_DELAY_US3);
      break;
    case 7:
      lcdPrintStr(0, 0, g_durationStr);
      lcdPrintDigit(3);
      button = lcdSetNumber3(0, 1, 1, &g_cursorPos, &g_3cursorPos, EEPROM_CUSTOM_DURATION_SEC3, EEPROM_CUSTOM_DURATION_MS3, EEPROM_CUSTOM_DURATION_US3);
      break;
    case 8:
      lcdPrintStr(0, 0, g_delayStr);
      lcdPrintDigit(4);
      button = lcdSetNumber3(0, 1, 1, &g_cursorPos, &g_3cursorPos, EEPROM_CUSTOM_DELAY_SEC4, EEPROM_CUSTOM_DELAY_MS4, EEPROM_CUSTOM_DELAY_US4);
      break;
    case 9:
      lcdPrintStr(0, 0, g_durationStr);
      lcdPrintDigit(4);
      button = lcdSetNumber3(0, 1, 1, &g_cursorPos, &g_3cursorPos, EEPROM_CUSTOM_DURATION_SEC4, EEPROM_CUSTOM_DURATION_MS4, EEPROM_CUSTOM_DURATION_US4);
      break;
    case 10:
      lcdPrintStr(0, 0, g_delayStr);
      lcdPrintDigit(5);
      button = lcdSetNumber3(0, 1, 1, &g_cursorPos, &g_3cursorPos, EEPROM_CUSTOM_DELAY_SEC5, EEPROM_CUSTOM_DELAY_MS5, EEPROM_CUSTOM_DELAY_US5);
      break;
    case 11:
      lcdPrintStr(0, 0, g_durationStr);
      lcdPrintDigit(5);
      button = lcdSetNumber3(0, 1, 1, &g_cursorPos, &g_3cursorPos, EEPROM_CUSTOM_DURATION_SEC5, EEPROM_CUSTOM_DURATION_MS5, EEPROM_CUSTOM_DURATION_US5);
      break;
    case 12:
      lcdPrintStr(0, 0, g_delayStr);
      lcdPrintDigit(6);
      button = lcdSetNumber3(0, 1, 1, &g_cursorPos, &g_3cursorPos, EEPROM_CUSTOM_DELAY_SEC6, EEPROM_CUSTOM_DELAY_MS6, EEPROM_CUSTOM_DELAY_US6);
      break;
    case 13:
      lcdPrintStr(0, 0, g_durationStr);
      lcdPrintDigit(6);
      button = lcdSetNumber3(0, 1, 1, &g_cursorPos, &g_3cursorPos, EEPROM_CUSTOM_DURATION_SEC6, EEPROM_CUSTOM_DURATION_MS6, EEPROM_CUSTOM_DURATION_US6);
      break;
        
    default:
      g_menuNum = 0;
  }
  
  handleMenuButton(button, numMenus);}


